Axis

Enum Axis 

pub enum Axis {
    Emulated {
        pos: Button,
        neg: Button,
    },
    Controller {
        controller_id: u32,
        axis: ControllerAxis,
        invert: bool,
        dead_zone: f64,
    },
    Mouse {
        axis: MouseAxis,
        over_extendable: bool,
        radius: f32,
    },
    MouseWheel {
        horizontal: bool,
    },
    Multiple(Vec<Axis>),
}
Represents any input represented by a float value from -1 to 1. Retrieve the value of this with axis_value.

Variants



Emulated

Represents an emulated analogue axis made up of pair of digital inputs, like W and S keyboard buttons or DPadUp and DPadDown controller buttons.

Fields

pos: Button

Positive button, when pressed down axis value will return 1 if neg is not pressed down.

neg: Button

Negative button, when pressed down axis value will return -1 if pos is not pressed down.



Controller

Represents an analogue axis of a controller.

Fields

controller_id: u32

A number representing a specific controller, assigned and reused in order of connection.

axis: ControllerAxis

The axis being bound

invert: bool

Whether or not to multiply the axis value by -1.

dead_zone: f64

Treat input values from -dead_zone to dead_zone as 0, linearly interpolate remaining ranges.



Mouse

Represents a mouse as a 2D input device

Fields

axis: MouseAxis

The axis being bound

over_extendable: bool

Should the API be allowed to return values outside [-1..1]?

radius: f32

Zone to which the movement is relative



MouseWheel

Represents the wheel on a PC mouse.

Fields

horizontal: bool

If this value is true then this axis is for the horizontal mouse wheel rather than the vertical mouse wheel.

You almost always want this false.



Multiple(Vec<Axis>)

Represents multiple input alternatives. Allows to bind more than one input to a single axis.