pub enum Button {
Key(VirtualKeyCode),
ScanCode(u32),
Mouse(MouseButton),
MouseWheel(ScrollDirection),
Controller(u32, ControllerButton),
}Expand description
A Button is any kind of digital input that the engine supports.
Variants
Key(VirtualKeyCode)
Virtual Keyboard keys, use this when the letter on the key matters more than the position of the key.
ScanCode(u32)
Scan code from keyboard, use this when the position of the key matters more than the letter on the key.
Mouse(MouseButton)
Mouse buttons
MouseWheel(ScrollDirection)
Mouse wheel (Do not use these with an emulated axis, instead use the MouseWheel axis.)
Controller(u32, ControllerButton)
Controller buttons matching SDL controller model. A tuple of sequential controller_id in order of connection and specific type of used controller button.