pub enum Axis {
Emulated {
pos: Button,
neg: Button,
},
Controller {
controller_id: u32,
axis: ControllerAxis,
invert: bool,
dead_zone: f64,
},
Mouse {
axis: MouseAxis,
over_extendable: bool,
radius: f32,
},
MouseWheel {
horizontal: bool,
},
Multiple(Vec<Axis>),
}Expand description
Represents any input represented by a float value from -1 to 1. Retrieve the value of this with axis_value.
Variants
Emulated
Represents an emulated analogue axis made up of pair of digital inputs,
like W and S keyboard buttons or DPadUp and DPadDown controller buttons.
Fields
Controller
Represents an analogue axis of a controller.
Fields

controller_id: u32A number representing a specific controller, assigned and reused in order of connection.

axis: ControllerAxisThe axis being bound
Mouse
Represents a mouse as a 2D input device
Fields
MouseWheel
Represents the wheel on a PC mouse.
Fields
Multiple(Vec<Axis>)
Represents multiple input alternatives. Allows to bind more than one input to a single axis.